@@ -1,16 +1,18 @@
 Rud.P <-
-function(cutscore, os, sem) 
+function(cutscore, theta, sem) 
 	 { 
-	 	nn <- length(os)
+  os<-theta
+	 	nn<-length(os)
 	 	nc <- length(cutscore)
 	 	
 	 	if(nn != length(sem)) stop("Ability and se of different length")
 	
-		esacc<-matrix(NA,length(cutscore), nn, dimnames = list(paste("cut at",cutscore), round(os,3)))
+		esacc<-matrix(NA,length(cutscore), nn, dimnames = list(paste("cut at",round(cutscore,3)), round(os,3)))
 		escon <-esacc
+		
 		for(j in 1:length(cutscore)){
 			cuts<-c(-Inf, cutscore[j], Inf)		 	
-	 		categ<-cut(os,cuts,labels=FALSE)
+	 		categ<-cut(os,cuts,labels=FALSE,right=FALSE)
 			
 		for(i in 1:nn) {
 			esacc[j,i]<-(pnorm(cuts[categ[i]+1],os[i],sem[i])-pnorm(cuts[categ[i]],os[i],sem[i]))
@@ -20,19 +22,21 @@ function(cutscore, os, sem)
 	if(nc ==1)	{
 		ans<- (list("Marginal" = cbind("Accuracy" = rowMeans(esacc), "Consistency" = rowMeans(escon)), "Conditional" = list("Accuracy" =t(esacc), "Consistency" = t(escon))))
 				
-			ans } else {
+			return(ans)
+		
+		} else {
 				
 				simul <- matrix(NA,nn, 2, dimnames = list(round(os,3), c("Accuracy", "Consistency")))
 				cuts <- c(-Inf, cutscore, Inf)
-				categ<-cut(os,cuts,labels=FALSE)
+				categ<-cut(os,cuts,labels=FALSE,right=FALSE)
 				
 				for(i in 1:nn){
 					simul[i,1] <- (pnorm(cuts[categ[i]+1],os[i],sem[i])-pnorm(cuts[categ[i]],os[i],sem[i]))
 					
-					what <- 0
+					sha <- 0
 			for(j in 1:(nc+1)){
-				what <- what + (pnorm(cuts[j+1],os[i],sem[i])-pnorm(cuts[j],os[i],sem[i]))^2}
-			simul[i,2]<-what}
+			  sha <- sha + (pnorm(cuts[j+1],os[i],sem[i])-pnorm(cuts[j],os[i],sem[i]))^2}
+			simul[i,2]<-sha}
 			
 			ans<- (list("Marginal" = rbind(cbind("Accuracy" = rowMeans(esacc), "Consistency" = rowMeans(escon)), "Simultaneous" = colMeans(simul)), "Conditional" = list("Accuracy" =cbind(t(esacc), "Simultaneous" =simul[,1]), "Consistency" = cbind(t(escon),"Simultaneous" =simul[,2]))))
 				ans}
