@@ -1,12 +1,11 @@
 iif <-
 function (ip, x, D = 1.7) 
 	{
-	    if (is.null(dim(ip))) 
-	        dim(ip) = c(1, 3)
+  
         p3 = irf(ip, x, D)$f
         q3 = 1 - p3
         
-        f<-matrix(NA,nrow = length(x),ncol = dim(ip)[1])
+        f<-matrix(NA, nrow = length(x), ncol = dim(ip)[1])
         
         for(i in 1:length(x)){ for(j in 1:dim(ip)[1]){
         		
